Contributors
------------
The following list of people who have contributed code or documentation
makes no claims about completeness.

* Andy Dustman
* John Eikenberry
* Vincent Pelletier
* Graeme Mathieson
* Federico Schwindt
* Brett Carter
* Mark Van den Borre
* Robert Buchholz
* Jens Vagelpohl
